@@ -2,7 +2,7 @@
 * This file is part of Converseen, an open-source batch image converter
 * and resizer.
 *
-* (C) Francesco Mondello 2009-2017
+* (C) Francesco Mondello 2009 - 2022
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -17,12 +17,13 @@
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
-* Contact e-mail: Faster <faster3ck@gmail.com>
+* Contact e-mail: Francesco Mondello <faster3ck@gmail.com>
 *
 */
 
 #include "formats.h"
 #include "thumbnailgeneratorthread.h"
+#include "globals.h"
 
 #define MAX_THUMB_W 320
 #define MAX_THUMB_H 240
@@ -114,8 +115,10 @@ void ThumbnailGeneratorThread::createThumbnail()
         img_dens_x = tmpImage.logicalDpiX();
         img_dens_y = tmpImage.logicalDpiY();
 
+        qreal scaleFactor = globals::Globals::scaleFactor();
+
         if (m_generateThumbnail) {
-            thumbnail = tmpImage.scaled(QSize(MAX_THUMB_W, MAX_THUMB_H),
+            thumbnail = tmpImage.scaled(QSize(MAX_THUMB_W, MAX_THUMB_H) * scaleFactor,
                                        Qt::KeepAspectRatio,
                                        Qt::SmoothTransformation);
 
@@ -124,6 +127,7 @@ void ThumbnailGeneratorThread::createThumbnail()
     else {
         try
         {
+            my_image.quiet(true);
             my_image.read(m_fileName.toStdString());
 
             img_width = my_image.columns();
